# Changelog

## [0.4.1](https://github.com/cademirch/snakemake-logger-plugin-rich/compare/v0.4.0...v0.4.1) (2025-10-01)


### Bug Fixes

* add emit impl ([#21](https://github.com/cademirch/snakemake-logger-plugin-rich/issues/21)) ([eb04515](https://github.com/cademirch/snakemake-logger-plugin-rich/commit/eb0451531daf750d28bae6c39895124bf181adcd))

## [0.4.0](https://github.com/cademirch/snakemake-logger-plugin-rich/compare/v0.3.1...v0.4.0) (2025-09-24)


### Miscellaneous Chores

* release 0.4.0 ([b4c289c](https://github.com/cademirch/snakemake-logger-plugin-rich/commit/b4c289cadcfd44a34384f7adffab21a90ed777ad))

## [0.3.1](https://github.com/cademirch/snakemake-logger-plugin-rich/compare/v0.3.0...v0.3.1) (2025-07-31)


### Bug Fixes

* add tests ([#15](https://github.com/cademirch/snakemake-logger-plugin-rich/issues/15)) ([e76c9a4](https://github.com/cademirch/snakemake-logger-plugin-rich/commit/e76c9a4291be40f7998e8e2ef727a4d1094af8e8))
* clean up readme; fix typing  ([#14](https://github.com/cademirch/snakemake-logger-plugin-rich/issues/14)) ([04e113f](https://github.com/cademirch/snakemake-logger-plugin-rich/commit/04e113f287a09475a0eb290a92589102620c7b09))


### Miscellaneous Chores

* release 0.3.1 ([667d4a9](https://github.com/cademirch/snakemake-logger-plugin-rich/commit/667d4a9d8fe286b21d3591b729befda1b7b7519b))

## [0.3.0](https://github.com/cademirch/snakemake-logger-plugin-rich/compare/v0.2.3...v0.3.0) (2025-07-31)


### Features

* Refactor eventhandler ([#13](https://github.com/cademirch/snakemake-logger-plugin-rich/issues/13)) ([b0f2188](https://github.com/cademirch/snakemake-logger-plugin-rich/commit/b0f2188e8146ccc176f110298458c3f26f57dc96))


### Bug Fixes

* migrate to pixi, add demo ([159d012](https://github.com/cademirch/snakemake-logger-plugin-rich/commit/159d0126cddaa088508f8054efcc3d3bad83ff40))

## [0.2.3](https://github.com/cademirch/snakemake-logger-plugin-rich/compare/v0.2.2...v0.2.3) (2025-03-10)


### Miscellaneous Chores

* release 0.2.3 ([3d82b9f](https://github.com/cademirch/snakemake-logger-plugin-rich/commit/3d82b9f3e764bab806914e8b94097f222161b28a))

## [0.2.2](https://github.com/cademirch/snakemake-logger-plugin-rich/compare/v0.2.1...v0.2.2) (2025-02-19)


### Bug Fixes

* loghandler class ([7f1c530](https://github.com/cademirch/snakemake-logger-plugin-rich/commit/7f1c530d6fca86ea38e2fe2e185a7da04f15f180))

## [0.2.1](https://github.com/cademirch/snakemake-logger-plugin-rich/compare/v0.2.0...v0.2.1) (2025-02-19)


### Bug Fixes

* update settings import ([5f46e6d](https://github.com/cademirch/snakemake-logger-plugin-rich/commit/5f46e6de57251b59c69dd5014195b011665c92f8))

## [0.2.0](https://github.com/cademirch/snakemake-logger-plugin-rich/compare/v0.1.5...v0.2.0) (2025-02-19)


### ⚠ BREAKING CHANGES

* python version

### Bug Fixes

* python version ([3772069](https://github.com/cademirch/snakemake-logger-plugin-rich/commit/3772069ce9c40c17fe17b003a78fe773c5b71312))


### Miscellaneous Chores

* release 0.2.0 ([4449860](https://github.com/cademirch/snakemake-logger-plugin-rich/commit/4449860a032ba304c3d6745a89dc155250c19fab))

## [0.1.5](https://github.com/cademirch/snakemake-logger-plugin-rich/compare/v0.1.4...v0.1.5) (2025-02-19)


### Bug Fixes

* ci ([2e0f93f](https://github.com/cademirch/snakemake-logger-plugin-rich/commit/2e0f93fa0c025ea16b19a00a6b550b60c4478174))

## [0.1.4](https://github.com/cademirch/snakemake-logger-plugin-rich/compare/v0.1.3...v0.1.4) (2025-02-19)


### Bug Fixes

* ci versions ([65f2cdd](https://github.com/cademirch/snakemake-logger-plugin-rich/commit/65f2cdd066849b3f6a333d6e56593f941859e14f))

## [0.1.3](https://github.com/cademirch/snakemake-logger-plugin-rich/compare/v0.1.2...v0.1.3) (2025-02-19)


### Bug Fixes

* fix release action ([a3c84f7](https://github.com/cademirch/snakemake-logger-plugin-rich/commit/a3c84f72ea3380d6cfd0ba89f9d628d939c189e8))

## [0.1.2](https://github.com/cademirch/snakemake-logger-plugin-rich/compare/0.1.1...v0.1.2) (2025-02-19)


### Bug Fixes

* :green_heart: add release-please ([8b3d39d](https://github.com/cademirch/snakemake-logger-plugin-rich/commit/8b3d39d8828daa4c9045622c06847e1cd13294e5))
* make work with newest interface ([c6f7377](https://github.com/cademirch/snakemake-logger-plugin-rich/commit/c6f73773636ee591bc750872c838deaeaeba62f6))

## [0.1.1] - 2024-11-03

- Added formatter and filter. 

## [0.1.0] - 2024-11-03

- Initial release.
